==> lnl-2.1.8.tar.gz: lnl-2.1.8/src/class_tab.h <==
#include	"party.h"
#include	"msg.h"

enum {
	CLASS_N_FIGHTER,
	CLASS_N_MONK,
	CLASS_N_HUNTER,
	CLASS_N_THIEF,
	CLASS_N_WIZARD,
	CLASS_N_SUMMONER,
	CLASS_N_PRIEST,
	CLASS_N_SHAMAN,
	CLASS_N_BARD,
	CLASS_N_BISHOP,
};

#if	0
typedef struct {
	n_msg_t	n_name;
	char	name[CLASS_NAME_MAX_LEN + 1];
	class_dflt_t	dflt;
	rate_t	abl_rate[ABL_KIND_MAX_N];
} class_t;

			HP MP,
			DEX STR QUI WIS INT CHA
			FIG MON HUN THI
			MAG SUM SOR ENC
			PRI SHA BAR NIN
#endif

class_t	class_tab[CLASS_MAX_N + 1];

class_t	class_dflt_tab[] = {
	{
		N_MSG_CLASS_FIGHTER, "",
		CLASS_DFLT_FIGHTER,
		{
			20,  0,
			20, 20, 20,  0,  0,  0,
			20,  0,  0,  0,
			 0,  0,  0,  0,
			 0,  0,  0,  0,
		},
	},
	{
		N_MSG_CLASS_MONK, "",
		CLASS_DFLT_MONK,
		{
			20,  0,
			20, 20, 20,  0,  0,  0,
			 0, 20,  0,  0,
			 0,  0,  0,  0,
			 0,  0,  0,  0,
		},
	},
	{
		N_MSG_CLASS_HUNTER, "",
		CLASS_DFLT_HUNTER,
		{
			15,  0,
			20, 20, 15,  0,  0,  0,
			10,  0, 20,  0,
			 0,  0,  0,  0,
			 0,  0,  0,  0,
		},
	},
	{
		N_MSG_CLASS_THIEF, "",
		CLASS_DFLT_THIEF,
		{
			15,  0,
			20, 10, 20,  0,  0,  0,
			15,  0,  0, 20,
			 0,  0,  0,  0,
			 0,  0,  0,  0,
		},
	},
	{
		N_MSG_CLASS_WIZARD, "",
		CLASS_DFLT_WIZARD,
		{
			10, 20,
			 0,  0,  0,  0, 20,  0,
			 0,  0,  0,  0,
			20, 15, 15,  0,
			 0,  0,  0,  0,
		},
	},
	{
		N_MSG_CLASS_SUMMONER, "",
		CLASS_DFLT_SUMMONER,
		{
			15, 20,
			 0,  0,  5,  0, 20,  0,
			20,  0,  0,  0,
			 0,  0,  0, 20,
			 0,  0,  0,  0,
		},
	},
	{
		N_MSG_CLASS_PRIEST, "",
		CLASS_DFLT_PRIEST,
		{
			20, 20,
			 0,  0,  0, 20,  0,  0,
			20,  0,  0,  0,
			 0,  0,  0,  0,
			20,  0,  0,  0,
		},
	},
	{
		N_MSG_CLASS_SHAMAN, "",
		CLASS_DFLT_SHAMAN,
		{
			15, 20,
			 0,  0,  5,  0,  0, 20,
			20,  0,  0,  0,
			 0,  0,  0,  0,
			 0, 20,  0,  0,
		},
	},
	{
		N_MSG_CLASS_BARD, "",
		CLASS_DFLT_BARD,
		{
			15,  0,
			20,  0,  5,  0,  0, 20,
			20,  0,  0,  0,
			 0,  0,  0,  0,
			 0,  0, 20,  0,
		},
	},
	{
		N_MSG_CLASS_BISHOP, "",
		CLASS_DFLT_BISHOP,
		{
			10, 15,
			 0,  0,  0, 15, 15,  0,
			 0,  0,  0,  0,
			15, 15,  0,  0,
			15,  0,  0,  0,
		},
	},
	{
		N_MSG_NULL, "",
		CLASS_DFLT_NULL,
		{
			 0,  0,
			 0,  0,  0,  0,  0,  0,
			 0,  0,  0,  0,
			 0,  0,  0,  0,
			 0,  0,  0,  0,
		},
	},
};

==> lnl-2.1.20.tar.gz: lnl-2.1.20/src/class_tab.h <==
/*****************************************************************
* L&L - Labyrinths & Legends
* Copyright (c) 1993-2003 YOSHIMURA Tomohiko All rights reserved.
* 
* Created by BowKenKen
*   e-mail: bowkenken@users.sourceforge.jp
*   URL: https://sourceforge.jp/projects/lnl/
* 
* License is GPL
* 
* ܥץϥե꡼եȥǤ
* ʤϡ Free Software Foundation ɽ
*  GNU ̸ͭѵΡ֥С󣲡
* ϤʹߤγƥС椫餤줫򤷡
* ΥС˽äܥץ
* ۤޤѹ뤳ȤǤޤ
* 
* ܥץͭѤȤϻפޤۤˤäƤϡ
* ԾڤŪŬˤĤƤΰۤݾڤޤ,
* ʤݾڤԤʤޤ
* ܺ٤ˤĤƤ GNU ̸ͭѵɤߤ
* 
* ʤϡܥץȰ GNU ̸ͭѵ
* μ̤äƤϤǤǤʤϡ
*   Free Software Foundation, Inc.,
*   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
* ؼ񤤤Ƥ
* 
* $Id: class_tab.h,v 1.6 2003/11/19 13:19:13 bowkenken Exp $
*****************************************************************/

#ifndef	CLASS_TAB_H
#define	CLASS_TAB_H

#include	"party.h"
#include	"msg.h"

enum {
	CLASS_N_FIGHTER,
	CLASS_N_MONK,
	CLASS_N_HUNTER,
	CLASS_N_THIEF,
	CLASS_N_WIZARD,
	CLASS_N_SUMMONER,
	CLASS_N_PRIEST,
	CLASS_N_SHAMAN,
	CLASS_N_BARD,
	CLASS_N_NINJA,
	CLASS_N_BISHOP,
};

#if	0
typedef struct {
	n_msg_t	n_name;
	char	name[CLASS_NAME_MAX_LEN + 1];
	class_dflt_t	dflt;
	rate_t	abl_rate[ABL_KIND_MAX_N];
} class_t;

			HP MP,
			DEX STR QUI WIS INT CHA
			FIG MON HUN THI
			MAG SUM SOR ENC
			PRI SHA BAR NIN
#endif

class_t	class_tab[CLASS_MAX_N + 1];

class_t	class_dflt_tab[] = {
	{
		N_MSG_CLASS_FIGHTER, "",
		CLASS_DFLT_FIGHTER,
		{
			20,  0,
			20, 20, 20,  0,  0,  0,
			20,  0,  0,  0,
			 0,  0,  0,  0,
			 0,  0,  0,  0,
		},
	},
	{
		N_MSG_CLASS_MONK, "",
		CLASS_DFLT_MONK,
		{
			20,  0,
			20, 20, 20,  0,  0,  0,
			 0, 20,  0,  0,
			 0,  0,  0,  0,
			 0,  0,  0,  0,
		},
	},
	{
		N_MSG_CLASS_HUNTER, "",
		CLASS_DFLT_HUNTER,
		{
			15,  0,
			20, 20, 15,  0,  0,  0,
			10,  0, 20,  0,
			 0,  0,  0,  0,
			 0,  0,  0,  0,
		},
	},
	{
		N_MSG_CLASS_THIEF, "",
		CLASS_DFLT_THIEF,
		{
			15,  0,
			20, 10, 20,  0,  0,  0,
			15,  0,  0, 20,
			 0,  0,  0,  0,
			 0,  0,  0,  0,
		},
	},
	{
		N_MSG_CLASS_WIZARD, "",
		CLASS_DFLT_WIZARD,
		{
			10, 20,
			 0,  0,  0,  0, 20,  0,
			 0,  0,  0,  0,
			20, 15, 15,  0,
			 0,  0,  0,  0,
		},
	},
	{
		N_MSG_CLASS_SUMMONER, "",
		CLASS_DFLT_SUMMONER,
		{
			15, 20,
			 0,  0,  5,  0, 20,  0,
			20,  0,  0,  0,
			 0,  0,  0, 20,
			 0,  0,  0,  0,
		},
	},
	{
		N_MSG_CLASS_PRIEST, "",
		CLASS_DFLT_PRIEST,
		{
			20, 20,
			 0,  0,  0, 20,  0,  0,
			20,  0,  0,  0,
			 0,  0,  0,  0,
			20,  0,  0,  0,
		},
	},
	{
		N_MSG_CLASS_SHAMAN, "",
		CLASS_DFLT_SHAMAN,
		{
			15, 20,
			 0,  0,  5,  0,  0, 20,
			20,  0,  0,  0,
			 0,  0,  0,  0,
			 0, 20,  0,  0,
		},
	},
	{
		N_MSG_CLASS_BARD, "",
		CLASS_DFLT_BARD,
		{
			15,  0,
			20,  0,  5,  0,  0, 20,
			20,  0,  0,  0,
			 0,  0,  0,  0,
			 0,  0, 20,  0,
		},
	},
	{
		N_MSG_CLASS_NINJA, "",
		CLASS_DFLT_NINJA,
		{
			20,  0,
			15, 10, 15,  0,  0,  0,
			20,  0,  0,  0,
			 0,  0,  0,  0,
			 0,  0,  0, 20,
		},
	},
	{
		N_MSG_CLASS_BISHOP, "",
		CLASS_DFLT_BISHOP,
		{
			10, 15,
			 0,  0,  0, 15, 15,  0,
			 0,  0,  0,  0,
			15, 15,  0,  0,
			15,  0,  0,  0,
		},
	},
	{
		N_MSG_NULL, "",
		CLASS_DFLT_NULL,
		{
			 0,  0,
			 0,  0,  0,  0,  0,  0,
			 0,  0,  0,  0,
			 0,  0,  0,  0,
			 0,  0,  0,  0,
		},
	},
};

#endif	/* CLASS_TAB_H */
